@@ -24,7 +24,7 @@ namespace=UUID("00abedb4-aa42-466c-9c01-fed23315a9b7")
 
 example_PhoneNumberSCO = Phonenumber(
                     id="phone-number--"+ str(uuid.uuid5(namespace, f"07890129093")),
-                    number="4407890129093",
+                    value="4407890129093",
                     country="GBR",
                     connection="mobile",
                     provider="Big Network"
