@@ -19,14 +19,14 @@ namespace=UUID("1abb62b9-e513-5f55-8e73-8f6d7b55c237")
 
 ### dogesec
 
-created_by_ref="identity--" + str(uuid.uuid5(namespace, f"dogesec"))
+DOGESEC_IDENTITY_REF="identity--" + str(uuid.uuid5(namespace, f"dogesec"))
 created="2020-01-01T00:00:00.000Z"
 modified="2020-01-01T00:00:00.000Z"
 schema_base="https://raw.githubusercontent.com/muchdogesec/stix2extensions/main/schemas/"
 
 ### mitre TLP:CLEAR and stix4doge
 
-object_marking_refs=[
+S2E_MARKING_REFS=[
     "marking-definition--94868c89-83c2-464b-929b-a1a8aa3c8487", # this is TLP:CLEAR
     "marking-definition--" + str(uuid.uuid5(namespace, f"stix2extensions")) # 
 ]
@@ -38,7 +38,7 @@ object_marking_refs=[
 
 phone_number_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"phone-number")), # extension-definition--14a97ee2-e666-5ada-a6bd-b7177f79e211
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=datetime(2020, 1, 1, tzinfo=UTC),
                         name="Phone Number",
@@ -48,14 +48,14 @@ phone_number_ExtensionDefinitionSMO = ExtensionDefinition(
                         extension_types=[
                             "new-sco"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### Cryptocurrency Transaction SMO
 
 cryptocurrency_transaction_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"cryptocurrency-transaction")), # extension-definition--151d042d-4dcf-5e44-843f-1024440318e5
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=datetime(2020, 1, 1, tzinfo=UTC),
                         name="Cryptocurrency Transaction",
@@ -65,14 +65,14 @@ cryptocurrency_transaction_ExtensionDefinitionSMO = ExtensionDefinition(
                         extension_types=[
                             "new-sco"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### Data Source SMO
 
 data_source_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"data-source")), # extension-definition--afeeb724-bce2-575e-af3d-d705842ea84b
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=modified,
                         name="Data Source",
@@ -82,14 +82,14 @@ data_source_ExtensionDefinitionSMO = ExtensionDefinition(
                         extension_types=[
                             "new-sco"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### Weakness SMO
 
 weakness_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"weakness")), # extension-definition--31725edc-7d81-5db7-908a-9134f322284a
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=datetime(2020, 1, 1, tzinfo=UTC),
                         name="Weakness",
@@ -99,14 +99,14 @@ weakness_ExtensionDefinitionSMO = ExtensionDefinition(
                         extension_types=[
                             "new-sdo"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### Exploit SMO
 
 exploit_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"exploit")), # extension-definition--5a047f57-0149-59b6-a079-e2d7c7ac799a
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=datetime(2020, 1, 1, tzinfo=UTC),
                         name="Exploit",
@@ -116,31 +116,31 @@ exploit_ExtensionDefinitionSMO = ExtensionDefinition(
                         extension_types=[
                             "new-sdo"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
-### Bank Card SMO
+### Payment Card SMO
 
-bank_card_ExtensionDefinitionSMO = ExtensionDefinition(
-                        id="extension-definition--" + str(uuid.uuid5(namespace, f"bank-card")), # extension-definition--7922f91a-ee77-58a5-8217-321ce6a2d6e0
-                        created_by_ref=created_by_ref,
+payment_card_ExtensionDefinitionSMO = ExtensionDefinition(
+                        id="extension-definition--" + str(uuid.uuid5(namespace, f"payment-card")), # extension-definition--
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=datetime(2020, 1, 1, tzinfo=UTC),
-                        name="Bank Card",
-                        description="This extension creates a new SCO that can be used to represent bank cards.",
-                        schema=schema_base+"scos/bank-card.json",
+                        name="Payment Card",
+                        description="This extension creates a new SCO that can be used to represent different types of payment card.",
+                        schema=schema_base+"scos/payment-card.json",
                         version="1.0",
                         extension_types=[
                             "new-sco"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### User Agent SMO
 
 user_agent_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"user-agent")), # extension-definition--7ca5afee-0e4e-5813-b643-de51538658cc
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=datetime(2020, 1, 1, tzinfo=UTC),
                         name="User Agent",
@@ -150,14 +150,14 @@ user_agent_ExtensionDefinitionSMO = ExtensionDefinition(
                         extension_types=[
                             "new-sco"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### Cryptocurrency Wallet SMO
 
 cryptocurrency_wallet_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"cryptocurrency-wallet")), # extension-definition--be78509e-6958-51b1-8b26-d17ee0eba2d7
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=datetime(2020, 1, 1, tzinfo=UTC),
                         name="Cryptocurrency Wallet",
@@ -167,14 +167,14 @@ cryptocurrency_wallet_ExtensionDefinitionSMO = ExtensionDefinition(
                         extension_types=[
                             "new-sco"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### Bank Account SMO
 
 bank_account_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"bank-account")), # extension-definition--f19f3291-6a84-5674-b311-d75a925d5bd9
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=datetime(2020, 1, 1, tzinfo=UTC),
                         name="Bank Account",
@@ -184,14 +184,14 @@ bank_account_ExtensionDefinitionSMO = ExtensionDefinition(
                         extension_types=[
                             "new-sco"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### Vulnerability Scoring Extension SMO
 
 vulnerability_scoring_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"vulnerability-scoring")), # extension-definition--2c5c13af-ee92-5246-9ba7-0b958f8cd34a
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=datetime(2025, 10, 3, 0, 0, tzinfo=UTC),
                         name="Vulnerability SDO Scoring Properties",
@@ -204,14 +204,14 @@ vulnerability_scoring_ExtensionDefinitionSMO = ExtensionDefinition(
                         extension_properties=[
                             "x_cvss",
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### Vulnerability OpenCTI Extension SMO
 
 vulnerability_opencti_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"vulnerability-opencti")), # xtension-definition--ec658473-1319-53b4-879f-488e47805554
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=modified,
                         name="Vulnerability SDO OpenCTI Properties",
@@ -269,14 +269,14 @@ vulnerability_opencti_ExtensionDefinitionSMO = ExtensionDefinition(
                             "x_opencti_epss_score",
                             "x_opencti_epss_percentile"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### Location OpenCTI Extension SMO
 
 location_opencti_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"location-opencti")), # extension-definition--b9c1f945-80be-519d-9d7f-0cede26032e9
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=modified,
                         name="Location SDO OpenCTI Properties",
@@ -290,14 +290,14 @@ location_opencti_ExtensionDefinitionSMO = ExtensionDefinition(
                             "x_opencti_aliases",
                             "x_opencti_location_type"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### Indicator Vulnerable CPEs Extension SMO
 
 indicator_vulnerable_cpes_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"indicator-vulnerable-cpes")), # extension-definition--ad995824-2901-5f6e-890b-561130a239d4
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=datetime(2020, 1, 1, tzinfo=UTC),
                         name="Indicator SDO Vulnerable CPEs Properties",
@@ -310,14 +310,14 @@ indicator_vulnerable_cpes_ExtensionDefinitionSMO = ExtensionDefinition(
                         extension_properties=[
                             "x_cpes"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### Report EPSS Scoring SMO
 
 report_epss_scoring_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"report-epss-scoring")), # extension-definition--f80cce10-5ac0-58d1-9e7e-b4ed0cc4dbb9
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=datetime(2020, 1, 1, tzinfo=UTC),
                         name="Report SDO EPSS Scoring Properties",
@@ -330,14 +330,14 @@ report_epss_scoring_ExtensionDefinitionSMO = ExtensionDefinition(
                         extension_properties=[
                             "x_epss"
                         ],
-                        object_marking_refs=object_marking_refs
+                        object_marking_refs=S2E_MARKING_REFS
                     )
 
 ### Software CPE SMO
 
 software_cpe_properties_ExtensionDefinitionSMO = ExtensionDefinition(
                         id="extension-definition--" + str(uuid.uuid5(namespace, f"software-cpe-properties")), # extension-definition--82cad0bb-0906-5885-95cc-cafe5ee0a500
-                        created_by_ref=created_by_ref,
+                        created_by_ref=DOGESEC_IDENTITY_REF,
                         created=created,
                         modified=datetime(2025, 10, 3, tzinfo=UTC),
                         name="Software SCO CPE Properties",
@@ -353,33 +353,5 @@ software_cpe_properties_ExtensionDefinitionSMO = ExtensionDefinition(
                             "x_created",
                             "x_modified"
                         ],
-                        object_marking_refs=object_marking_refs
-                    )
-
-### Attack Flow SMO
-
-attack_flow_ExtensionDefinitionSMO = ExtensionDefinition(
-                        type="extension-definition",
-                        id="extension-definition--fb9c968a-745b-4ade-9b25-c324172197f4",
-                        spec_version="2.1",
-                        created="2022-08-02T19:34:35.143Z",
-                        modified="2022-08-02T19:34:35.143Z",
-                        name="Attack Flow",
-                        description="Extends STIX 2.1 with features to create Attack Flows.",
-                        created_by_ref="identity--fb9c968a-745b-4ade-9b25-c324172197f4",
-                        schema="https://center-for-threat-informed-defense.github.io/attack-flow/stix/attack-flow-schema-2.0.0.json",
-                        version="2.0.0",
-                        extension_types=["new-sdo"],
-                        external_references=[
-                            {
-                                "source_name": "Documentation",
-                                "description": "Documentation for Attack Flow",
-                                "url": "https://center-for-threat-informed-defense.github.io/attack-flow",
-                            },
-                            {
-                                "source_name": "GitHub",
-                                "description": "Source code repository for Attack Flow",
-                                "url": "https://github.com/center-for-threat-informed-defense/attack-flow",
-                            },
-                        ],
+                        object_marking_refs=S2E_MARKING_REFS
                     )
