@@ -12,8 +12,8 @@ _type = 'user-agent'
     ('type', TypeProperty(_type, spec_version='2.1')),
     ('spec_version', StringProperty(fixed='2.1')),
     ('id', IDProperty(_type, spec_version='2.1')),
-    ('string', StringProperty(required=True)),
+    ('value', StringProperty(required=True)),
     # ('extensions', ExtensionsProperty(spec_version='2.1'))
-], extension_name=user_agent_ExtensionDefinitionSMO.id, id_contrib_props=['string'])
+], extension_name=user_agent_ExtensionDefinitionSMO.id, id_contrib_props=['value'])
 class UserAgent(object):
     pass
